==> camel-kafka-connector-0.7.3-src.zip: apache-camel-kafkaconnector-0.7.3/tests/itests-azure-storage-blob/src/test/java/org/apache/camel/kafkaconnector/azure/storage/blob/sink/TestBlobConfiguration.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.camel.kafkaconnector.azure.storage.blob.sink;

import com.azure.storage.blob.BlobServiceClient;
import org.apache.camel.component.azure.storage.blob.BlobConfiguration;
import org.apache.camel.kafkaconnector.azure.storage.services.AzureStorageBlobClientUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class TestBlobConfiguration extends BlobConfiguration {
    private static final Logger LOG = LoggerFactory.getLogger(TestBlobConfiguration.class);
    private BlobServiceClient serviceClient;

    @Override
    public BlobServiceClient getServiceClient() {
        if (serviceClient == null) {
            LOG.info("Creating a custom BlobServiceClient");
            serviceClient = AzureStorageBlobClientUtils.getClient();
        }

        return serviceClient;
    }
}

==> camel-kafka-connector-4.10.2-src.zip: apache-camel-kafkaconnector-3.20.0/tests/itests-azure-storage-blob/src/test/java/org/apache/camel/kafkaconnector/azure/storage/blob/sink/TestBlobConfiguration.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.camel.kafkaconnector.azure.storage.blob.sink;

import com.azure.storage.blob.BlobServiceClient;
import org.apache.camel.component.azure.storage.blob.BlobConfiguration;
import org.apache.camel.test.infra.azure.storage.blob.clients.AzureStorageBlobClientUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class TestBlobConfiguration extends BlobConfiguration {
    private static final Logger LOG = LoggerFactory.getLogger(TestBlobConfiguration.class);
    private BlobServiceClient serviceClient;

    @Override
    public BlobServiceClient getServiceClient() {
        if (serviceClient == null) {
            LOG.info("Creating a custom BlobServiceClient");
            serviceClient = AzureStorageBlobClientUtils.getClient();
        }

        return serviceClient;
    }
}
